@@ -122,7 +122,7 @@ all_coords <- as.matrix(st_coordinates(count_dat))
 
 ## ----mesh, cache=FALSE----------------------------------------------
 # make a hull and mesh for spatial model
-hull <- fm_nonconvex_hull_inla(
+hull <- fm_nonconvex_hull(
   count_dat,
   convex = 200,
   concave = 350
